@@ -4,11 +4,10 @@ package Mail::Builder;
 
 use Moose;
 
-use version;
+our $VERSION = "2.06";
 our $AUTHORITY = 'cpan:MAROS';
-our $VERSION = version->new("2.05");
 
-use Mail::Builder::Role::TypeConstraints;
+use Mail::Builder::TypeConstraints;
 
 use Carp;
 
@@ -39,6 +38,13 @@ has 'htmltext' => (
     trigger         => \&_generate_plaintext,
 );
 
+has 'date' => (
+    is              => 'rw',
+    isa             => 'Mail::Builder::Type::Date',
+    lazy_build      => 1,
+    clearer         => 'clear_date',
+);
+
 has 'subject' => (
     is              => 'rw',
     isa             => 'Str',
@@ -302,6 +308,7 @@ sub purge_cache {
     my ($self) = @_;
     
     $self->clear_messageid;
+    $self->clear_date;
     
     # Remove plaintext if it has been derived form htmltext
     if ($self->_plaintext_autotext) {
@@ -408,6 +415,12 @@ sub _build_html {
     return $mime_part;
 }
 
+sub _build_date {
+    my ($self) = @_;
+    Class::MOP::load_class('Email::Date::Format');
+    Email::Date::Format::email_date();
+}
+
 
 sub build_message {
     my ($self) = @_;
@@ -431,6 +444,7 @@ sub build_message {
         'To'            => $self->to->join(','),
         'Cc'            => $self->cc->join(','),
         'Bcc'           => $self->bcc->join(','),
+        'Date'          => $self->date,
         'Subject'       => encode('MIME-Header',$self->subject),
         'Message-ID'    => $messageid->in_brackets(),
         'X-Priority'    => $self->priority,
@@ -612,7 +626,7 @@ Each call to this method also changes the C<messageid>.
 =head3 purge_cache
 
 Emptys the attachment and image cache and removes the plaintext text if it has
-been autogenerated from html text. Also deletes the Message ID.
+been autogenerated from html text. Also resets the Message ID nd date header.
 
 =head2 Accessors 
 
@@ -709,6 +723,12 @@ manipulating the list of recipients. e.g.
  OR
  $obj->to->add(Email::Address)
 
+=head3 date
+
+e-mail date header. Accepts/returns a RFC2822 date. Also accepts a 
+DateTime object or epoch integer. Will be autogenerated if not provided.
+C<clear_date> can be used to reset the date accessor.
+
 =head3 language
 
 e-mail text language. Additionally the C<has_language> and C<clear_language>
